@@ -900,7 +900,7 @@ OPARI2_Directive::find_next_word( void )
         while ( m_pline < m_lines.size() )
         {
             string::size_type wbeg = m_lines[ m_pline ].find_first_not_of( " \t", m_ppos );
-            if ( m_lines[ m_pline ][ wbeg ] == '\\' || wbeg == string::npos )
+            if ( wbeg == string::npos || m_lines[ m_pline ][ wbeg ] == '\\' )
             {
                 ++m_pline;
                 if ( m_pline < m_lines.size() )
