@@ -163,7 +163,7 @@ OPARI2_FortranParser::is_sub_unit_header( void )
     }
 
     //Check if we are in Fortran77 and have a character in column 6
-    if ( ( m_options.form & F_FIX ) && m_lowline[ 5 ] != ' ' && m_lowline.find( "\t" ) > 6 )
+    if ( ( m_options.form & F_FIX ) && m_lowline.length() >= 6 && m_lowline[ 5 ] != ' ' && m_lowline.find( "\t" ) > 6 )
     {
         continuation = true;
     }
@@ -266,7 +266,7 @@ OPARI2_FortranParser::is_sub_unit_header( void )
     //Check if we leave an contains block
     inContains = inContains && sline.find( "endmodule" ) == string::npos;
 
-    if ( sline[ sline.length() - 1 ] == '&' )
+    if ( sline.length() && sline[ sline.length() - 1 ] == '&' )
     {
         continuation = true;
     }
@@ -663,7 +663,7 @@ OPARI2_FortranParser::get_next_line( void )
         {
             m_continuation = m_next_is_continuation;
             string::size_type amp = m_line.find_last_not_of( " \t" );
-            if ( m_line[ amp ] == '&' )
+            if ( amp != string::npos && m_line[ amp ] == '&' )
             {
                 m_continuation = true;
             }
@@ -683,7 +683,8 @@ void
 OPARI2_FortranParser::handle_line_directive( const string::size_type lstart )
 {
     /* line directive */
-    if ( ( isdigit( m_line[ m_line.find_first_not_of( " \t", lstart + 1 ) ] ) ) )
+    string::size_type loc = m_line.find_first_not_of( " \t", lstart + 1 );
+    if ( loc != string::npos && isdigit( m_line[ loc ] ) )
     {
         string::size_type nrstart, nrend;
         string            filename;
